add_registry_to_linker

Function add_registry_to_linker 

pub fn add_registry_to_linker(
    linker: &mut Linker,
    ctx: impl AsContextMut,
    registry: impl Registry,
) -> Result<(), Error>
Adds the registry to the linker to define the numcodecs:abc/registry interface.

Errors

Errors if adding the registry to the linker fails.