pub fn add_registry_to_linker(
linker: &mut Linker,
ctx: impl AsContextMut,
registry: impl Registry,
) -> Result<(), Error>Expand description
Adds the registry to the linker to define the numcodecs:abc/registry
interface.
Errors
Errors if adding the registry to the linker fails.